@@ -10,8 +10,8 @@ TEMPLATES = NETNIR_DIRS.get("templates", None)
 DOMAIN = NETNIR_CONFIG.get("domain", None)
 OUTPUT_DIR = NETNIR_DIRS.get("output", None)
 SERVICE_NAME = os.environ.get("NETNIR_SERVICE_NAME", "netnir")
-NETNIR_USER = os.environ.get("NETNIR_USER", None)
-NETNIR_PASS = os.environ.get("NETNIR_PASS", None)
+NETNIR_USER = os.environ.get("NETNIR_USER")
+NETNIR_PASS = os.environ.get("NETNIR_PASS")
 NORNIR_CONFIG = NETNIR_CONFIG["nornir"]["config"]
 HIER_DIR = NETNIR_DIRS.get("hier", None)
 NR = InitNornir(config_file=os.path.expanduser(NORNIR_CONFIG))
